==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/ts/Block_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Blockwerkzeuge</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Blockwerkzeuge anzeigen</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>Blo&amp;ck</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+115"/>
        <source>Leading or trailing spaces.</source>
        <translation>Führende oder nachfolgende Leerzeichen.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Blockname ist leer.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Blockname ist ungültig.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Block &quot;%1&quot; ist bereits vorhanden&lt;br&gt;und wird überschrieben.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Block existiert bereits.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Block Daten</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Blockname:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>block 1</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/ts/Block_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Blockwerkzeuge</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Blockwerkzeuge anzeigen</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>Blo&amp;ck</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+134"/>
        <source>Leading or trailing spaces.</source>
        <translation>Führende oder nachfolgende Leerzeichen.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Blockname ist leer.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Blockname ist ungültig.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Block &quot;%1&quot; ist bereits vorhanden&lt;br&gt;und wird überschrieben.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Block existiert bereits.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Block Daten</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Blockname:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>block 1</translation>
    </message>
</context>
<context>
    <name>LayoutDialog</name>
    <message>
        <source>Layout</source>
        <translation type="vanished">Layout</translation>
    </message>
    <message>
        <source>Leading or trailing spaces.</source>
        <translation type="vanished">Führende oder nachfolgende Leerzeichen.</translation>
    </message>
    <message>
        <source>Layout name is empty.</source>
        <translation type="vanished">Layoutname ist leer.</translation>
    </message>
    <message>
        <source>Layout name is invalid.</source>
        <translation type="vanished">Layoutname ist ungültig.</translation>
    </message>
    <message>
        <source>Layout &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation type="vanished">Layout &quot;%1&quot; ist bereits vorhanden&lt;br&gt;und wird überschrieben.</translation>
    </message>
    <message>
        <source>Layout already exists.</source>
        <translation type="vanished">Layout existiert bereits.</translation>
    </message>
    <message>
        <source>Layout Data</source>
        <translation type="vanished">Layout Daten</translation>
    </message>
    <message>
        <source>Layout name:</source>
        <translation type="vanished">Layoutname:</translation>
    </message>
</context>
</TS>
